@@ -1,8 +1,9 @@
 from quick_orm.core import Database
 from sqlalchemy import Column, String
 
-class User(object):
-    __metaclass__ = Database.DefaultMeta
+__metaclass__ = Database.DefaultMeta
+
+class User:
     name = Column(String(30))
 
 Database.register()
